@@ -462,15 +462,13 @@ class WordType(caching.base.CachingMixin,models.Model):
             patt.extend(phones[i:])
             patterns.append('^'+' '.join(patt) +'$')
         neighs = WordType.objects.filter(Label__regex="^[^{<]").extra(
-                    select = {
-                        'ur': """(SELECT GROUP_CONCAT(buckeyebrowser_segmenttype.Label SEPARATOR ' ')
+                    where = ["""(SELECT GROUP_CONCAT(buckeyebrowser_segmenttype.Label SEPARATOR ' ')
                                 FROM buckeyebrowser_underlying
                                 INNER JOIN buckeyebrowser_segmenttype
                                 ON buckeyebrowser_segmenttype.id
                                     = buckeyebrowser_underlying.SegmentType_id
                                 WHERE buckeyebrowser_underlying.WordType_id
-                                    =buckeyebrowser_wordtype.id)"""},
-                    where = ["ur REGEXP %s"],
+                                    =buckeyebrowser_wordtype.id) REGEXP %s"""],
                     params = ['|'.join(patterns)])
         nd = len(neighs)
         fwnd = sum([ x.getFreq() for x in neighs])
@@ -509,26 +507,22 @@ class WordType(caching.base.CachingMixin,models.Model):
             pattern = '^'+' '.join(patt) +'.*$'
             totPattern = '^'+' '.join([any_segment] * (i+1)) +'.*$'
             count = WordType.objects.filter(Label__regex="^[^{<]").extra(
-                    select = {
-                        'ur': """(SELECT GROUP_CONCAT(buckeyebrowser_segmenttype.Label SEPARATOR ' ')
+                    where = ["""(SELECT GROUP_CONCAT(buckeyebrowser_segmenttype.Label SEPARATOR ' ')
                                 FROM buckeyebrowser_underlying
                                 INNER JOIN buckeyebrowser_segmenttype
                                 ON buckeyebrowser_segmenttype.id
                                     = buckeyebrowser_underlying.SegmentType_id
                                 WHERE buckeyebrowser_underlying.WordType_id
-                                    =buckeyebrowser_wordtype.id)"""},
-                    where = ["ur REGEXP %s"],
+                                    =buckeyebrowser_wordtype.id) REGEXP %s"""],
                     params = [pattern])
             totCount = WordType.objects.filter(Label__regex="^[^{<]").extra(
-                    select = {
-                        'ur': """(SELECT GROUP_CONCAT(buckeyebrowser_segmenttype.Label SEPARATOR ' ')
+                    where = ["""(SELECT GROUP_CONCAT(buckeyebrowser_segmenttype.Label SEPARATOR ' ')
                                 FROM buckeyebrowser_underlying
                                 INNER JOIN buckeyebrowser_segmenttype
                                 ON buckeyebrowser_segmenttype.id
                                     = buckeyebrowser_underlying.SegmentType_id
                                 WHERE buckeyebrowser_underlying.WordType_id
-                                    =buckeyebrowser_wordtype.id)"""},
-                    where = ["ur REGEXP %s"],
+                                    =buckeyebrowser_wordtype.id) REGEXP %s"""],
                     params = [totPattern])
             SPprob += float(count) / float(totCount)
             if i != len(phones)-1:
@@ -537,26 +531,22 @@ class WordType(caching.base.CachingMixin,models.Model):
                 pattern = '^'+' '.join(patt) +'.*$'
                 totPattern = '^'+' '.join([any_segment] * (i+2)) +'.*$'
                 count = WordType.objects.filter(Label__regex="^[^{<]").extra(
-                    select = {
-                        'ur': """(SELECT GROUP_CONCAT(buckeyebrowser_segmenttype.Label SEPARATOR ' ')
+                    where = ["""(SELECT GROUP_CONCAT(buckeyebrowser_segmenttype.Label SEPARATOR ' ')
                                 FROM buckeyebrowser_underlying
                                 INNER JOIN buckeyebrowser_segmenttype
                                 ON buckeyebrowser_segmenttype.id
                                     = buckeyebrowser_underlying.SegmentType_id
                                 WHERE buckeyebrowser_underlying.WordType_id
-                                    =buckeyebrowser_wordtype.id)"""},
-                    where = ["ur REGEXP %s"],
+                                    =buckeyebrowser_wordtype.id) REGEXP %s"""],
                     params = [pattern])
                 totCount = WordType.objects.filter(Label__regex="^[^{<]").extra(
-                    select = {
-                        'ur': """(SELECT GROUP_CONCAT(buckeyebrowser_segmenttype.Label SEPARATOR ' ')
+                    where = ["""(SELECT GROUP_CONCAT(buckeyebrowser_segmenttype.Label SEPARATOR ' ')
                                 FROM buckeyebrowser_underlying
                                 INNER JOIN buckeyebrowser_segmenttype
                                 ON buckeyebrowser_segmenttype.id
                                     = buckeyebrowser_underlying.SegmentType_id
                                 WHERE buckeyebrowser_underlying.WordType_id
-                                    =buckeyebrowser_wordtype.id)"""},
-                    where = ["ur REGEXP %s"],
+                                    =buckeyebrowser_wordtype.id) REGEXP %s"""],
                     params = [totPattern])
                 BPprob += float(count) / float(totCount)
         SPprob = SPprob / float(len(phones))
